# Open and check full tree
library(ape)
tree<-read.tree("F:\\PhD work\\Conservation status and defence\\conservtree.nwk")
summary(tree)
is.ultrametric(tree)
tree$node.label<-NULL

# View tree
plot(tree,show.tip.label=F,no.margin=T,edge.color="dark blue")

# Read in datafile (inc. check)
conserv<-read.csv("F:\\PhD work\\Conservation status and defence\\conservdat.csv",header=T,row.names=1)
conserv$cd<-as.factor(conserv$cd)
conserv$threat<-as.factor(conserv$threat)
conserv$status<-as.factor(conserv$status)
summary(conserv)
conserv[1:10,]

##############################################################################################

# Phylogenetic logistic regression of conservation status~chemical defence
library(phylolm)
conserv$threat<-as.numeric(conserv$threat)-1
threatmod<-phyloglm(threat~cd,data=conserv,phy=tree,method="logistic_MPLE")
summary(threatmod) # beta=0.596, se=0.196, z=3.045, P=0.002
# Note, AIC with phyloglm = 739.74, AIC with glm = 801.54, deltaAIC in favour of phylogenetic model = 61.80, w = 1, evidence ratio = 2.63e13
# Note also that the alpha parameter ranges between 0 and 1, with low values relating to high phylogenetic signal. For this model estimated alpha = 0.016

# Phylogenetic signal of residuals from model
library(phytools)
tdr<-threatmod$residuals
phylosig(tree,tdr,method="K",test=T,nsim=5000) # Significant signal (K=0.065, P=0.024))
phylosig(tree,tdr,method="lambda",test=T) # Significant signal (lambda=0.653, P=3e-26))

# Back-transformed estimates from logistic regression
tc<-function(x){1/(1+(exp(-x)))}
int<-threatmod$coefficients[1]
names(int)<-NULL
cd<-threatmod$coefficients[2]
names(cd)<-NULL
notox<-tc(int)
tox<-tc(int+cd)
threat<-c(NonToxic=notox,Toxic=tox)
threat # Pthreat[non-toxic]=0.187, Pthreat[toxic]=0.294
threat["Toxic"]/threat["NonToxic"] # Toxic species are ~1.6x as likely to be threatened

##############################################################################################

# Plotting threat model
barplot(c(0.187,0.294),main="",ylim=c(0,0.4),ylab="Probability of being threatened",cex.lab=1.5,col=c("black","red"))
axis(side=1,at=c(0.7,1.9),labels=c("Non-toxic","Toxic"),cex.axis=1.5)

##############################################################################################

# Phylogenetic signal of conservation status
library(caper)
conserv$sp<-rownames(conserv)
pdat<-comparative.data(tree,conserv,sp)
phylo.d(pdat,binvar=threat,permut=5000) # d=0.495, Pno=0, Pbm=0.0002

##############################################################################################

# Pagel's test
library(phytools)
library(geiger)
chem<-conserv$cd
names(chem)<-rownames(conserv)
th<-conserv$threat
names(th)<-rownames(conserv)
pag<-fitPagel(tree,chem,th,method="fitDiscrete")
pag # LR=16.344, P=0.003

# Pagel's test with constraints to examine directionality
library(corHMM)
cor<-data.frame(rownames(conserv),conserv$cd,conserv$threat)
ermod<-corDISC(tree,cor,ntraits=2,model="ER")
symmod<-corDISC(tree,cor,ntraits=2,model="SYM")
ardmod<-corDISC(tree,cor,ntraits=2,model="ARD")
ermod # logLik=-795.497, AICc=1592.999
symmod # logLik=-788.335, AICc=1584.719
ardmod # logLik=-750.986, AICc=1518.151
# ARD is the best model

cormat<-rate.mat.maker(hrm=FALSE,ntraits=2,model="ARD")
indmat<-rate.par.eq(cormat, eq.par=c(3,8)) #q12=q34
indmat<-rate.par.eq(indmat, eq.par=c(1,6)) #q21=q43
indmat<-rate.par.eq(indmat, eq.par=c(5,6)) #q13=q24
indmat<-rate.par.eq(indmat, eq.par=c(2,4)) #q31=q42
cormod<-corDISC(tree,cor,ntraits=2,rate.mat=cormat,model="ARD")
indmod<-corDISC(tree,cor,ntraits=2,rate.mat=indmat,model="ARD")
lr<-function(small,big,df){
likrat<--2*(small-big)
p<-1-pchisq(likrat,df)
return(list(LR=likrat,P=p))
}
lr(indmod$loglik,cormod$loglik,4)
# Consistent with phytools version, cormod is better (LR=15.805, P=0.003)

ordermat<-rate.par.eq(cormat, eq.par=c(3,5)) #q12=q13
ordermod<-corDISC(tree,cor,ntraits=2,rate.mat=ordermat,model="ARD")
lr(ordermod$loglik,cormod$loglik,1)
# Toxicity is gained first, followed by threat status (LR=11.714, P=0.0006)

##############################################################################################

# Phylogenetic Poisson regression of Red List category~chemical defence
library(phylolm)
statusmod<-phyloglm(status~cd,data=conserv,phy=tree,method="poisson_GEE")
summary(nstatusmod) # beta=0.049, se=0.022, z=2.263, P=0.024

# Phylogenetic signal of residuals from model
library(phytools)
sdr<-statusmod$residuals
phylosig(tree,sdr,method="K",test=T,nsim=5000) # Significant signal (K=0.071, P=0.009))
phylosig(tree,sdr,method="lambda",test=T) # Significant signal (lambda=0.701, P=2.9e-38))

##############################################################################################

# Plotting status model by count
barplot(table(conserv$cd,conserv$status),main="",ylim=c(0,600),ylab="Number of species",cex.lab=1.5,xlab="Conservation status",col=c("black","red"),legend=c("Non-toxic","Toxic"),names.arg=c("LC","NT","VU","EN","CR","EX"))

# Plotting status model by proportion
tab<-table(conserv$cd,conserv$status)
for (i in 1:length(colnames(tab))){tab[,i]<-tab[,i]/sum(tab[,i])}
barplot(tab,main="",ylim=c(0,1),ylab="Proportion of species",cex.lab=1.5,xlab="Conservation status",col=c("black","red"),names.arg=c("LC","NT","VU","EN","CR","EX"))




